import { createRoot } from "react-dom/client";
import * as React from "react";
import "./index.css";

// استيراد أدوات تحسين الأداء الجديدة
import { 
  initializePerformanceKit, 
  detectImageFormats, 
  addPreconnect, 
  runAfterPageLoad,
  logPerformanceInfo,
  deferNonCritical
} from "@/components/perf";

// بدء تسجيل وقت بدء التطبيق للقياس
performance.mark('app-start');

// إضافة إتصالات مسبقة للنطاقات الهامة
addPreconnect([
  'https://res.cloudinary.com',
  'https://fonts.googleapis.com',
  'https://fonts.gstatic.com',
  'https://apis.google.com'
]);

// وظيفة لكشف تنسيقات الصور والإعدادات الأخرى مبكرًا
const setupBrowserFeatures = () => {
  try {
    // كشف دعم تنسيقات الصور (WebP/AVIF)
    detectImageFormats().then(formats => {
      if (formats.webp) {
        document.documentElement.classList.add('webp-support');
      }
      if (formats.avif) {
        document.documentElement.classList.add('avif-support');
      }
      
      // تخزين في متغير عام للوصول من أي مكان
      window.__imageSupport = formats;
    });
    
    // تعطيل الحركات للأجهزة التي تفضل ذلك
    if (window.matchMedia && window.matchMedia('(prefers-reduced-motion: reduce)').matches) {
      document.documentElement.classList.add('reduce-motion');
    }
    
    // إضافة معلومات الجهاز لتحسين عرض المحتوى
    const isMobile = /iPhone|iPad|iPod|Android/i.test(navigator.userAgent);
    document.documentElement.classList.add(isMobile ? 'is-mobile' : 'is-desktop');
    
    // إعداد سمات للوضع المظلم
    const prefersDarkMode = window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches;
    document.documentElement.classList.add(prefersDarkMode ? 'dark-theme' : 'light-theme');
  } catch (e) {
    console.warn('خطأ في اختبار ميزات المتصفح', e);
  }
};

// استيراد مكون التطبيق الرئيسي
import App from "./App";

// مكون واجهة التحميل المحسنة
const EnhancedLoadingFallback = () => (
  <div className="splash-container" aria-label="جاري تحميل التطبيق">
    <div className="logo-placeholder">
      <div className="skeleton-loader" role="progressbar" aria-busy="true"></div>
    </div>
    <div className="loading-indicator">
      <p className="loading-text">جاري التحميل...</p>
      <div className="loading-progress"></div>
    </div>
  </div>
);

// تهيئة التطبيق بشكل محسن
const initApp = () => {
  const rootElement = document.getElementById("root");
  if (!rootElement) {
    console.error('عنصر الجذر غير موجود!');
    return;
  }
  
  // إنشاء جذر التطبيق
  const appRoot = createRoot(rootElement);
  
  // عرض التطبيق مع إمكانية إضافة Suspense و ErrorBoundary
  appRoot.render(
    <App />
  );
  
  // قياس وقت تهيئة التطبيق
  performance.mark('app-initialized');
  
  // تفعيل أدوات تحسين الأداء
  initializePerformanceKit();
};

// بدء تشغيل التطبيق مع تحسينات الأداء
const startApp = () => {
  // إعداد ميزات المتصفح مبكرًا
  setupBrowserFeatures();
  
  // بدء تهيئة التطبيق بناءً على حالة المستند
  if (document.readyState === 'loading') {
    document.addEventListener('DOMContentLoaded', initApp);
  } else {
    initApp();
  }
};

// بدء تشغيل التطبيق
startApp();

// إضافة قياسات محسنة للأداء بعد اكتمال التحميل
window.addEventListener('load', () => {
  performance.mark('app-fully-loaded');
  
  try {
    performance.measure('total-load-time', 'app-start', 'app-fully-loaded');
    const loadTime = performance.getEntriesByName('total-load-time')[0].duration;
    console.log('✅ إجمالي وقت تحميل التطبيق:', Math.round(loadTime), 'ms');
  } catch (e) {
    // تجاهل أخطاء القياس
  }
  
  // تسجيل معلومات أداء مفصلة
  deferNonCritical(() => {
    logPerformanceInfo();
  }, 2000);
  
  // تحميل المكونات غير الضرورية بعد التحميل الرئيسي
  runAfterPageLoad(() => {
    console.log('🔄 تحميل المكونات غير الأساسية والتحليلات');
    
    // يمكن تحميل أدوات التحليلات وملفات الجافاسكريبت الإضافية هنا
  });
});
